@@ -6,10 +6,10 @@ c.units <- function(..., recursive = FALSE) {
     for (i in 2:length(args)) {
       if (!inherits(args[[i]], "units"))
         stop(paste("argument", i, "is not of class units"))
-      if (!ud.are.convertible(units(args[[i]]), u))
+      tr = try(units(args[[i]]) <- u)
+	  if (class(tr) == "try-error")
         stop(paste("argument", i, 
                    "has units that are not convertible to that of the first argument"))
-      units(args[[i]]) = u
     }
   x = unlist(args)
   as.units(x, u)
